==> zen-cart-v1.2.0-l10n-jp-2.zip: zen-cart-v1.2.0-l10n-jp-2/admin/includes/languages/japanese/define_pages_editor.php <==
<?php
//
// +----------------------------------------------------------------------+
// |zen-cart Open Source E-commerce                                       |
// +----------------------------------------------------------------------+
// | Copyright (c) 2003 The zen-cart developers                           |
// |                                                                      |
// | http://www.zen-cart.com/index.php                                    |
// |                                                                      |
// | Portions Copyright (c) 2003 osCommerce                               |
// +----------------------------------------------------------------------+
// | This source file is subject to version 2.0 of the GPL license,       |
// | that is bundled with this package in the file LICENSE, and is        |
// | available through the world-wide-web at the following url:           |
// | http://www.zen-cart.com/license/2_0.txt.                             |
// | If you did not receive a copy of the zen-cart license and are unable |
// | to obtain it through the world-wide-web, please send a note to       |
// | license@zen-cart.com so we can mail you a copy immediately.          |
// +----------------------------------------------------------------------+
// $Id: define_pages_editor.php,v 1.3 2004/11/03 07:24:01 shidairiki Exp $
//

define('HEADING_TITLE', '֥ڡԽ: ');
define('NAVBAR_TITLE', '֥ڡԽ');

define('TEXT_INFO_EDIT_PAGE', 'Խڡ:');

define('TEXT_INFO_MAIN_PAGE', 'ᥤڡ');

define('TEXT_INFO_SHIPPINGINFO', 'ʤˤĤ');
define('TEXT_INFO_PRIVACY', 'Ŀ;ݸؿ');
define('TEXT_INFO_CONDITIONS', 'ȤΤѤˤĤ');
define('TEXT_INFO_CONTACT_US', '䤤碌');
define('TEXT_INFO_CHECKOUT_SUCCESS', 'åȴλ');

define('TEXT_INFO_PAGE_2', 'Page 2');
define('TEXT_INFO_PAGE_3', 'Page 3');
define('TEXT_INFO_PAGE_4', 'Page 4');

define('TEXT_FILE_DOES_NOT_EXIST', 'ե뤬¸ߤޤ: %s');

define('ERROR_FILE_NOT_WRITEABLE', '顼: ե˽񤭹ߤǤޤ󡣰ʲΥե񤭹߸¤ꤷƤ: %s');

define('TEXT_INFO_SELECT_FILE', 'Խե');
define('TEXT_INFO_EDITING', 'եԽ:');
?>

==> zen-cart-v1.3.0.2-l10n-jp-2.zip: zen-cart-v1.3.0.2-l10n-jp-2/admin/includes/languages/japanese/define_pages_editor.php <==
<?php
//
// +----------------------------------------------------------------------+
// |zen-cart Open Source E-commerce                                       |
// +----------------------------------------------------------------------+
// | Copyright (c) 2003 The zen-cart developers                           |
// |                                                                      |
// | http://www.zen-cart.com/index.php                                    |
// |                                                                      |
// | Portions Copyright (c) 2003 osCommerce                               |
// +----------------------------------------------------------------------+
// | This source file is subject to version 2.0 of the GPL license,       |
// | that is bundled with this package in the file LICENSE, and is        |
// | available through the world-wide-web at the following url:           |
// | http://www.zen-cart.com/license/2_0.txt.                             |
// | If you did not receive a copy of the zen-cart license and are unable |
// | to obtain it through the world-wide-web, please send a note to       |
// | license@zen-cart.com so we can mail you a copy immediately.          |
// +----------------------------------------------------------------------+
// $Id: define_pages_editor.php 1969 2005-09-13 06:57:21Z drbyte $
//

define('HEADING_TITLE', '֥ڡԽ: ');
define('NAVBAR_TITLE', '֥ڡԽ');

define('TEXT_INFO_EDIT_PAGE', 'Խڡ:');

define('TEXT_INFO_MAIN_PAGE', 'ᥤڡ');

define('TEXT_INFO_SHIPPINGINFO', 'ʤˤĤ');
define('TEXT_INFO_PRIVACY', 'Ŀ;ݸ');
define('TEXT_INFO_CONDITIONS', 'ȤΤѤˤĤ');
define('TEXT_INFO_CONTACT_US', '䤤碌');
define('TEXT_INFO_CHECKOUT_SUCCESS', 'åȴλ');

define('TEXT_INFO_PAGE_2', 'Page 2');
define('TEXT_INFO_PAGE_3', 'Page 3');
define('TEXT_INFO_PAGE_4', 'Page 4');

define('TEXT_FILE_DOES_NOT_EXIST', 'ե뤬¸ߤޤ: %s');

define('ERROR_FILE_NOT_WRITEABLE', '顼: ե˽񤭹ߤǤޤ󡣰ʲΥե񤭹߸¤ꤷƤ: %s');

define('TEXT_INFO_SELECT_FILE', 'Խե');
define('TEXT_INFO_EDITING', 'եԽ:');

define('TEXT_INFO_CAUTION',':ƥץ졼ȥС饤ɥǥ쥯ȥˤեԽ褦ˤƤ:  /languages/' . $_SESSION['language'] . '/html_includes/' . $template_dir . '<br />
ե򹹿ɬХååפäƤ');
?>
